@@ -2,4 +2,5 @@
 python-implementation for room
 """
 from threading import Event, Thread
-from src.wechaty.accessory import Accessory
+
+from ..accessory import Accessory
